@@ -1,10 +1,10 @@
 from dataframe import DataFrame, DataFrameFrom2dArray, combine
 from factors import Factor
-from parsers import DF2CSV, DF2ARFF, TabDialect, Access2000Dialect, SpaceDialect, DF2Excel, CommaDialect, DF2Sqlite, ParserError, DF2HTMLTable
+from parsers import DF2CSV, DF2ARFF, TabDialect, Access2000Dialect, SpaceDialect, DF2Excel, CommaDialect, DF2Sqlite, ParserError, DF2HTMLTable, DF2TSV
 
 __all__ = [
     'DataFrame', 'Factor', 'DataFrameFrom2dArray', 'combine',
-    'DF2CSV', 'DF2Excel', 'DF2HTMLTable', 'DF2Sqlite', 'DF2ARFF', 
+    'DF2CSV', 'DF2Excel', 'DF2HTMLTable', 'DF2Sqlite', 'DF2ARFF', 'DF2TSV', 
     'TabDialect', 'Access2000Dialect', 'SpaceDialect', 
     'CommaDialect', 'ParserError',
     
