@@ -974,8 +974,14 @@ class DataFrame(object):
         def compare_by_index(indexa, indexb):
             """Compare to rows by the fields in the specified order."""
             for field, asc in ziped:
-                compresult = cmp(self.value_dict[field][indexa], 
-                                 self.value_dict[field][indexb])
+                try:
+                    compresult = cmp(self.value_dict[field][indexa], 
+                                     self.value_dict[field][indexb])
+                except AttributeError, e:
+                    if str(e).find("'NotImplementedType' object has no attribute 'view'") != -1:
+                        compresult = -1
+                    else:
+                        raise e                
                 if compresult != 0:
                     if asc:
                         return compresult
@@ -1278,14 +1284,15 @@ class _RowNamesAttribute(object):
     def update_dictionary(self, obj):
         if not obj._row_names_ordered is None:
             lookup = {}
-            for row_no, value in enumerate(obj._row_names_ordered):
-                try:
+            try:
+                for (row_no, value) in enumerate(obj._row_names_ordered):
                     if value in lookup:
                         raise ValueError("Duplicate row name: %s" % value)
-                except: #happens if 'value in lookup' fails (not hashable?)
-                    print 'issue is with %s' % value
-                    raise
-                lookup[value] = row_no
+                    else:
+                        lookup[value] = row_no
+            except: #happens if 'value in lookup' fails (not hashable?)
+                print 'issue is with %s' % value
+                raise
             obj._row_names_dict = lookup
 DataFrame.row_names = _RowNamesAttribute()
 
@@ -1429,6 +1436,7 @@ class IteratorPlusLength:
 
 try:
     import rpy2.robjects as ro
+    import rpy2.robjects.conversion
     import rpy2.rinterface as rinterface
     import rpy2.robjects.numpy2ri
     previous_py2ri = ro.conversion.py2ri
