@@ -305,7 +305,7 @@ class DF2CSV:
         for row in file_object:
             if comment_character and row.startswith(comment_character):
                 continue
-            row = row.strip().split(sep)
+            row = row.rstrip().split(sep)
             #_unquote(dialect.quotechar, row)
             for i in xrange(0, number_of_columns):
                 try:
