@@ -32,7 +32,7 @@ import unittest
 import os
 import numpy
 from dataframe import DataFrame, DataFrameFrom2dArray
-from parsers import TabDialect, DF2CSV, DF2ARFF, DF2Excel
+from parsers import TabDialect, DF2CSV, DF2ARFF, DF2Excel, DF2TSV
 from factors import Factor
 import cPickle
 import StringIO
@@ -819,6 +819,19 @@ class DataFrameCSVTest(unittest.TestCase):
         a.drop_column("Field2")
         self.assertEqual(a, b)
 
+    def testTSVEmtyFirstColumn(self):
+        conv= DF2TSV()
+        a = DataFrame( { "Field1": [1, 2,3,4,5,6], "Field2": ['def','','jl','abx','hgi','pqr'], 'Field3': [7.0,8.0,9.0,10.0,11.0,12.0]}, ['Field2','Field1', 'Field3'])
+        o = open("test.txt", "wb")
+        conv.write(a,o)
+        o.close()
+        o = open("test.txt", "rb")
+        b = conv.read(o) #note the lack of 'handle_quotes'
+        o.close()
+        self.assertEqual(a, b)
+
+
+
 class DataFrameSharedDataSemanticTests(unittest.TestCase):
     """Unlike R Dataframes the descendands of one of my Dataframes share their data.
     Which also means that sort will lead to trouble..."""
